# OARepo requests

This repository provides extensions to the Invenio requests, namely:

* `/api/<model>/<id>/requests` endpoint for creating and listing 
  requests for a specific record.
* `/api/requests` endpoint for listing all requests which adds the option
  to use UI serialization.
* couple of common requests for curation workflows, such as reopening 
  published record, deleting published record, approving drafts. 
